@@ -55,19 +55,28 @@ func (e *Executor) Setup() error {
 }
 
 func (e *Executor) setCurrentDir() error {
+	// If the entrypoint is already set, we don't need to do anything
+	if e.Entrypoint != "" {
+		return nil
+	}
+
+	// Default the directory to the current working directory
 	if e.Dir == "" {
 		wd, err := os.Getwd()
 		if err != nil {
 			return err
 		}
 		e.Dir = wd
-	} else if !filepath.IsAbs(e.Dir) {
-		abs, err := filepath.Abs(e.Dir)
-		if err != nil {
-			return err
-		}
-		e.Dir = abs
 	}
+
+	// Search for a taskfile
+	root, err := read.ExistsWalk(e.Dir)
+	if err != nil {
+		return err
+	}
+	e.Dir = filepath.Dir(root)
+	e.Entrypoint = filepath.Base(root)
+
 	return nil
 }
 
