@@ -676,6 +676,7 @@ func TestPromptInSummary(t *testing.T) {
 		t.Run(test.name, func(t *testing.T) {
 			var inBuff bytes.Buffer
 			var outBuff bytes.Buffer
+			var errBuff bytes.Buffer
 
 			inBuff.Write([]byte(test.input))
 
@@ -683,6 +684,7 @@ func TestPromptInSummary(t *testing.T) {
 				Dir:         dir,
 				Stdin:       &inBuff,
 				Stdout:      &outBuff,
+				Stderr:      &errBuff,
 				AssumesTerm: true,
 			}
 			require.NoError(t, e.Setup())
@@ -702,6 +704,7 @@ func TestPromptWithIndirectTask(t *testing.T) {
 	const dir = "testdata/prompt"
 	var inBuff bytes.Buffer
 	var outBuff bytes.Buffer
+	var errBuff bytes.Buffer
 
 	inBuff.Write([]byte("y\n"))
 
@@ -709,6 +712,7 @@ func TestPromptWithIndirectTask(t *testing.T) {
 		Dir:         dir,
 		Stdin:       &inBuff,
 		Stdout:      &outBuff,
+		Stderr:      &errBuff,
 		AssumesTerm: true,
 	}
 	require.NoError(t, e.Setup())
@@ -732,6 +736,7 @@ func TestPromptAssumeYes(t *testing.T) {
 		t.Run(test.name, func(t *testing.T) {
 			var inBuff bytes.Buffer
 			var outBuff bytes.Buffer
+			var errBuff bytes.Buffer
 
 			// always cancel the prompt so we can require.Error
 			inBuff.Write([]byte("\n"))
@@ -740,6 +745,7 @@ func TestPromptAssumeYes(t *testing.T) {
 				Dir:       dir,
 				Stdin:     &inBuff,
 				Stdout:    &outBuff,
+				Stderr:    &errBuff,
 				AssumeYes: test.assumeYes,
 			}
 			require.NoError(t, e.Setup())
@@ -840,7 +846,7 @@ func TestStatusVariables(t *testing.T) {
 	require.NoError(t, e.Setup())
 	require.NoError(t, e.Run(context.Background(), taskfile.Call{Task: "build"}))
 
-	assert.Contains(t, buff.String(), "a41e7948dcd321db412ce61d3d5c9864")
+	assert.Contains(t, buff.String(), "3e464c4b03f4b65d740e1e130d4d108a")
 
 	inf, err := os.Stat(filepathext.SmartJoin(dir, "source.txt"))
 	require.NoError(t, err)
